@@ -85,7 +85,9 @@ class Basic(DefinitionBase, CoreServiceInterface):
             else:
                 self.cachedict[sid][meth_name][obj_name] = obj
             return True
-        except:
+        except Exception as e:
+            if isinstance(e, SyntaxError):
+                raise
             return False
 
     def clear_cache(self, sid, meth_name=None, obj_name=None):
@@ -162,7 +164,7 @@ class Basic(DefinitionBase, CoreServiceInterface):
                 thread.daemon = True
                 thread.start()
                 print success
-            except:
+            except Exception:
                 print failed
         print
 
