@@ -1416,7 +1416,7 @@ class CoreWsdl(CoreServiceInterface):
                         break
                 fd.close()
             try:
-                if lang.lower() not in ('fr', 'ru', 'en'):
+                if lang.lower() not in ('uk', 'fr', 'ru', 'en'):
                     lang = "en"
             except AttributeError:
                 lang = "en"
