@@ -130,7 +130,7 @@ def _getattr(obj, attr):
 
 import argparse
 import textwrap as _textwrap
-from calculate.lib.utils.text import get_term_size, _u, _u8
+from calculate.lib.utils.text import get_term_size, _u, _u8, _uu8
 
 
 class RawAndDefaultsHelpFormatter(argparse.HelpFormatter):
@@ -143,7 +143,7 @@ class RawAndDefaultsHelpFormatter(argparse.HelpFormatter):
 
     def _split_lines(self, text, width):
         text = self._whitespace_matcher.sub(' ', _u(text)).strip()
-        return _textwrap.wrap(_u(text), width)
+        return _uu8(*_textwrap.wrap(text, width))
 
 
 def get_method_argparser(view, args, cl_core=False):
